@@ -1,35 +1,40 @@
 import concurrent.futures
-from collections import namedtuple
 import json
-from typing import List
 import sys
+from collections import namedtuple
+from typing import List
 
-from importlib_metadata import distributions
-
-from packaging.markers import UndefinedEnvironmentName, UndefinedComparison
-from packaging.requirements import Requirement, InvalidRequirement
-from packaging.specifiers import SpecifierSet
-from packaging.version import parse as version_parse
-from packaging.utils import canonicalize_name
 import requests
+from importlib_metadata import distributions
+from packaging.markers import UndefinedComparison, UndefinedEnvironmentName
+from packaging.requirements import InvalidRequirement, Requirement
+from packaging.specifiers import SpecifierSet
+from packaging.utils import canonicalize_name
+from packaging.version import parse as version_parse
 
 from django.apps import apps as django_apps
 from django.db import models, transaction
 
 from allianceauth.services.hooks import get_extension_logger
+from app_utils.logging import LoggerAddTag
 
 from . import __title__
 from .app_settings import (
     PACKAGE_MONITOR_INCLUDE_PACKAGES,
     PACKAGE_MONITOR_SHOW_ALL_PACKAGES,
 )
-from .utils import LoggerAddTag
-
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 _DistributionInfo = namedtuple("_DistributionInfo", ["name", "files", "distribution"])
 
 
+def _none_2_empty(text) -> str:
+    """Translate None to empty string."""
+    if text is None:
+        return ""
+    return text
+
+
 def _parse_requirements(requires: list) -> List[Requirement]:
     """Parses requirements from a distribution and returns it.
     Invalid requirements will be ignored
@@ -298,15 +303,28 @@ class DistributionManager(models.Manager):
                 else:
                     used_by = []
 
+                name = _none_2_empty(package["distribution"].metadata["Name"])
+                apps = _none_2_empty(
+                    json.dumps(sorted(package["apps"], key=str.casefold))
+                )
+                used_by = _none_2_empty(json.dumps(used_by))
+                installed_version = _none_2_empty(package["distribution"].version)
+                latest_version = str(package["latest"]) if package["latest"] else ""
+                description = _none_2_empty(
+                    metadata_value(package["distribution"], "Summary")
+                )
+                website_url = _none_2_empty(
+                    metadata_value(package["distribution"], "Home-page")
+                )
                 obj = self.model(
-                    name=package["distribution"].metadata["Name"],
-                    apps=json.dumps(sorted(package["apps"], key=str.casefold)),
-                    used_by=json.dumps(used_by),
-                    installed_version=package["distribution"].version,
-                    latest_version=str(package["latest"]) if package["latest"] else "",
+                    name=name,
+                    apps=apps,
+                    used_by=used_by,
+                    installed_version=installed_version,
+                    latest_version=latest_version,
                     is_outdated=is_outdated,
-                    description=metadata_value(package["distribution"], "Summary"),
-                    website_url=metadata_value(package["distribution"], "Home-page"),
+                    description=description,
+                    website_url=website_url,
                 )
                 obj.calc_has_installed_apps()
                 distributions.append(obj)
